@@ -128,6 +128,27 @@ class TestWorkerCore:
         processor.start()
         assert len(processor.destination.results) == 2
 
+    def test_processor_dict(self):
+        class Output(BaseModel):
+            key: str
+            newkey: str
+
+        class MyProcessor(Processor):
+            def process(self, input, id):
+                return Output(key=input.get("key"), newkey="newval")
+
+        msgs = [{"key": "1"}, {"key": "2"}, {"key": "3"}]
+        settings = ProcessorSettings(name="processor", version="0.0.0", description="")
+        processor = MyProcessor(settings, input_class=dict, output_class=Output)
+        processor.parse_args(
+            args="--in-kind MEM --out-kind MEM --out-topic test".split()
+        )
+        processor.source.data = msgs
+        processor.start()
+        assert len(processor.destination.results) == 3
+        m = processor.destination.results[0]
+        assert m.get("newkey") == "newval"
+
     def test_processor(self):
         class Input(BaseModel):
             key: str
